@@ -4,7 +4,7 @@
 #include <QtCore>
 #include <QCoreApplication>
 #include "dabout.h"
-#include <Phonon>
+
 
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindow)
@@ -19,6 +19,8 @@ MainWindow::MainWindow(QWidget *parent)
     connect(netAccessManStream, SIGNAL(finished(QNetworkReply*)), this, SLOT(streamFinished(QNetworkReply*)));
     ui->plainTextEdit->hide();
     links = new QStringList();
+
+    music =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource(""));
 }
 
 MainWindow::~MainWindow()
@@ -225,23 +227,30 @@ void MainWindow::on_actionAbout_triggered()
 }
 
 void MainWindow::on_btnPlay_clicked(){
-    if (ui->lstItems->currentRow()>-1){
-	stream("http://www.goear.com/tracker758.php?f="+links->at(ui->lstItems->currentRow()));
+    //if (music)
+    if (music->state()==2){
+	music->pause();
+	ui->btnPlay->setText("Play");
+    }else if (music->state()==4){
+	music->play();
+    }else{
+	music->clear();
+	if (ui->lstItems->currentRow()>-1){
+	    stream("http://www.goear.com/tracker758.php?f="+links->at(ui->lstItems->currentRow()));
+	}
     }
 }
 
 void MainWindow::streamFinished(QNetworkReply *reply)
 {
     if (reply->error() != QNetworkReply::NoError) {
-	//qDebug() << "Error in" << reply->url() << ":" << reply->errorString();
-	ui->edtSong->setText("Goear is Down");
+	ui->edtSong->setText("Network Problem Can't access Goear");
 	reply->deleteLater();
 	return;
     }
     QVariant redir = reply->attribute(QNetworkRequest::RedirectionTargetAttribute);
     if (redir.isValid()) {
 	QUrl url = redir.toUrl();
-	//qDebug() << "must go to:" << url;
 	if (url.isRelative()) {
 	    url.setScheme(reply->url().scheme());
 	    url.setEncodedHost(reply->url().encodedHost());
@@ -251,14 +260,12 @@ void MainWindow::streamFinished(QNetworkReply *reply)
 	reply->deleteLater();
 	return;
     }
-   // qDebug() << "ContentType:" << reply->header(QNetworkRequest::ContentTypeHeader).toString();
 
     downloadedItem = reply->readAll();
 
     if (reply->header(QNetworkRequest::ContentTypeHeader).toString()=="text/xml"){
 	QString link=downloadedItem;
 
-	//ui->plainTextEdit->show();
 	ui->plainTextEdit->document()->setPlainText(downloadedItem);
 
 	int linkBegins=link.indexOf("path=\"")+6;
@@ -269,10 +276,12 @@ void MainWindow::streamFinished(QNetworkReply *reply)
 	//ui->plainTextEdit->hide();
 
 	QUrl url=link;
-	Phonon::MediaObject *music =Phonon::createPlayer(Phonon::MusicCategory,Phonon::MediaSource(url));
-	music->play();
-	//connect(music, SIGNAL(aboutToFinish())(finished(QNetworkReply*)), this, SLOT(streamFinished(QNetworkReply*)));
 
+	music->clearQueue();
+	music->enqueue(url);
+	music->play();
+	ui->btnPlay->setText("Pause");
+	ui->btnStop->setEnabled(true);
 
     }else if (reply->header(QNetworkRequest::ContentTypeHeader).toString()=="text/html"){
 	ui->lstItems->clear();
@@ -305,3 +314,9 @@ void MainWindow::streamFinished(QNetworkReply *reply)
 
     reply->deleteLater();
 }
+
+void MainWindow::on_btnStop_clicked()
+{
+    music->stop();
+    ui->btnStop->setEnabled(false);
+}
